@@ -49,6 +49,9 @@
 #include "pages/password/gis-password-page.h"
 #include "pages/summary/gis-summary-page.h"
 
+#define VENDOR_PAGES_GROUP "pages"
+#define VENDOR_PAGES_SKIP_KEY "skip"
+
 static gboolean force_existing_user_mode;
 
 typedef void (*PreparePage) (GisDriver *driver);
@@ -101,21 +104,36 @@ static gchar **
 pages_to_skip_from_file (void)
 {
   GKeyFile *skip_pages_file;
-  gchar **skip_pages;
+  gchar **skip_pages = NULL;
+  GError *error = NULL;
 
+  /* VENDOR_CONF_FILE points to a keyfile containing vendor customization
+   * options. This code will look for options under the "pages" group, and
+   * supports the following keys:
+   *   - skip (optional): list of pages to be skipped.
+   *
+   * This is how this file would look on a vendor image:
+   *
+   *   [pages]
+   *   skip=language
+   */
   skip_pages_file = g_key_file_new ();
-  /* TODO: put the skipfile somewhere sensible */
-  if (g_key_file_load_from_file (skip_pages_file, "/tmp/skip_pages_file",
-                                 G_KEY_FILE_NONE,
-                                 NULL)) {
-    skip_pages = g_key_file_get_string_list (skip_pages_file, "pages", "skip",
-                                             NULL, NULL);
-    g_key_file_free (skip_pages_file);
+  if (!g_key_file_load_from_file (skip_pages_file, VENDOR_CONF_FILE,
+                                  G_KEY_FILE_NONE, &error)) {
+    if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT))
+      g_warning ("Could not read file %s: %s", VENDOR_CONF_FILE, error->message);
 
-    return skip_pages;
+    g_error_free (error);
+    goto out;
   }
 
-  return NULL;
+  skip_pages = g_key_file_get_string_list (skip_pages_file, VENDOR_PAGES_GROUP,
+                                           VENDOR_PAGES_SKIP_KEY, NULL, NULL);
+
+ out:
+  g_key_file_free (skip_pages_file);
+
+  return skip_pages;
 }
 
 static void
